@@ -14,7 +14,7 @@
 """ Implementations of the session-based and cookie-based extractor and
     challenge plugins.
 
-$Id: session.py 80262 2007-09-27 23:47:04Z srichter $
+$Id: session.py 97574 2009-03-06 13:11:03Z nadako $
 """
 __docformat__ = 'restructuredtext'
 
@@ -28,8 +28,8 @@ from zope.publisher.interfaces.http import IHTTPRequest
 from zope.session.interfaces import ISession
 from zope.traversing.browser.absoluteurl import absoluteURL
 
-from zope.app.component import hooks
-from zope.app.container.contained import Contained
+from zope.site import hooks
+from zope.container.contained import Contained
 from zope.app.authentication.interfaces import ICredentialsPlugin
 
 class ISessionCredentials(Interface):
